@@ -9,7 +9,25 @@ import (
 	"github.com/patrickhener/goshs/utils"
 )
 
+func (fs *FileServer) handleInvisible(w http.ResponseWriter) {
+	hj, ok := w.(http.Hijacker)
+	if !ok {
+		return
+	}
+
+	conn, _, err := hj.Hijack()
+	if err != nil {
+		return
+	}
+
+	conn.Close()
+}
+
 func (fs *FileServer) handleError(w http.ResponseWriter, req *http.Request, err error, status int) {
+	if fs.Invisible {
+		fs.handleInvisible(w)
+		return
+	}
 	// Set header to status
 	w.WriteHeader(status)
 
@@ -22,8 +40,14 @@ func (fs *FileServer) handleError(w http.ResponseWriter, req *http.Request, err
 	// Construct error for template filling
 	e.ErrorCode = status
 	e.ErrorMessage = err.Error()
-	e.Directory = &directory{
-		AbsPath: path.Join(fs.Webroot, req.URL.Path),
+	if fs.Silent {
+		e.Directory = &directory{
+			AbsPath: "silent mode",
+		}
+	} else {
+		e.Directory = &directory{
+			AbsPath: path.Join(fs.Webroot, req.URL.Path),
+		}
 	}
 	e.GoshsVersion = fs.Version
 
