@@ -64,7 +64,8 @@ var (
 	webhookEventsParsed = []string{}
 	whitelist           = ""
 	trustedProxies      = ""
-	noMDNS              = false
+	MDNS                = false
+	invisible           = false
 )
 
 // Man page
@@ -86,6 +87,7 @@ Web server options:
   -nc, --no-clipboard   Disable the clipboard sharing           (default: false)
   -nd, --no-delete      Disable the delete option               (default: false)
   -si, --silent         Running without dir listing             (default: false)
+  -I,  --invisible      Invisible mode                          (default: false)
   -c,  --cli            Enable cli (only with auth and tls)     (default: false)
   -e,  --embedded       Show embedded files in UI               (default: false)
   -o,  --output         Write output to logfile                 (default: false)
@@ -115,8 +117,8 @@ Authentication options:
   -H,  --hash           Hash a password for file based ACLs
 
 Connection restriction:
-  -ipw, --ip-whitelist             Comma seperated list of IPs to whitelist
-  -tpw, --trusted-proxy-whitelist  Comma seperated list of trusted proxies
+  -ipw, --ip-whitelist             Comma separated list of IPs to whitelist
+  -tpw, --trusted-proxy-whitelist  Comma separated list of trusted proxies
 
 Webhook options:
   -W,  --webhook            Enable webhook support                                       (default: false)
@@ -131,7 +133,7 @@ Misc options:
   -P  --print-config  Print sample config to STDOUT           (default: false)
   -u  --user          Drop privs to user (unix only)          (default: current user)
       --update        Update goshs to most recent version
-  -nm --no-mdns       Disable zeroconf mDNS registration      (default: false)
+  -m  --mdns          Disable zeroconf mDNS registration      (default: false)
   -V  --verbose       Activate verbose log output             (default: false)
   -v                  Print the current goshs version
 
@@ -234,8 +236,10 @@ func flags() (*bool, *bool, *bool, *bool, *bool, *bool) {
 	flag.StringVar(&trustedProxies, "trusted-proxy-whitelist", trustedProxies, "")
 	flag.StringVar(&uploadFolder, "uf", uploadFolder, "")
 	flag.StringVar(&uploadFolder, "upload-folder", uploadFolder, "")
-	flag.BoolVar(&noMDNS, "nm", noMDNS, "Disable zeroconf mDNS registration")
-	flag.BoolVar(&noMDNS, "no-mdns", noMDNS, "Disable zeroconf mDNS registration")
+	flag.BoolVar(&MDNS, "m", MDNS, "Enable zeroconf mDNS registration")
+	flag.BoolVar(&MDNS, "mdns", MDNS, "Enable zeroconf mDNS registration")
+	flag.BoolVar(&invisible, "I", invisible, "Enable invisible mode")
+	flag.BoolVar(&invisible, "invisible", invisible, "Enable invisible mode")
 
 	updateGoshs := flag.Bool("update", false, "update")
 	hash := flag.Bool("H", false, "hash")
@@ -271,6 +275,17 @@ func resolveInterface() {
 }
 
 func sanityChecks() {
+	// Sanity check for invisible mode
+	if invisible {
+		if sftp || webdav {
+			sftp = false
+			webdav = false
+			MDNS = false
+			silent = false
+			logger.Warn("Invisible mode activated, disabling SFTP, WebDAV, silent mode and mDNS support")
+		}
+	}
+
 	// Sanity check for upload only vs read only
 	if uploadOnly && readOnly {
 		logger.Fatal("You can only select either 'upload only' or 'read only', not both.")
@@ -396,6 +411,7 @@ func init() {
 		sftpHostKeyfile = cfg.SFTPHostKeyFile
 		whitelist = cfg.Whitelist
 		trustedProxies = cfg.TrustedProxies
+		invisible = cfg.Invisible
 
 		// Abspath for webroot
 		// Trim trailing / for linux/mac and \ for windows
@@ -544,6 +560,7 @@ func main() {
 		NoClipboard:  noClipboard,
 		NoDelete:     noDelete,
 		Silent:       silent,
+		Invisible:    invisible,
 		Embedded:     embedded,
 		Webhook:      *webhook,
 		Verbose:      verbose,
@@ -552,7 +569,7 @@ func main() {
 	}
 
 	// Zeroconf mDNS
-	if !noMDNS {
+	if MDNS {
 		err = utils.RegisterZeroconfMDNS(ssl, port, webdav, webdavPort, sftp, sftpPort)
 		if err != nil {
 			logger.Warnf("error registering zeroconf mDNS: %+v", err)
